@@ -53,6 +53,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QLoggingCategory>
 #include <tiffio.h>
 
+// To enable AVIF/HEIF/JPEG-XL metadata support in Exiv2
+#include <exiv2/exiv2.hpp>
+
+#ifdef KIMAGEANNOTATOR_CAN_LOAD_TRANSLATIONS
+#include <kImageAnnotator/KImageAnnotator.h>
+#endif
+
 namespace
 {
 Q_DECLARE_LOGGING_CATEGORY(LibTiffLog)
@@ -146,6 +153,11 @@ private:
 
 int main(int argc, char *argv[])
 {
+    // enable AVIF/HEIF/JPEG-XL metadata support
+#ifdef EXV_ENABLE_BMFF
+    Exiv2::enableBMFF(true);
+#endif
+
 #ifdef HAVE_TIFF
     TIFFSetWarningHandler(handleTiffWarning);
     TIFFSetErrorHandler(handleTiffError);
@@ -194,6 +206,10 @@ int main(int argc, char *argv[])
     // to be async rather than using exec().
     qApp->sendPostedEvents(nullptr, QEvent::DeferredDelete);
 
+#ifdef KIMAGEANNOTATOR_CAN_LOAD_TRANSLATIONS
+    kImageAnnotator::loadTranslations();
+#endif
+
     return app.exec();
 }
 
