@@ -56,16 +56,16 @@ HudLabel::~HudLabel()
 void HudLabel::setText(const QString &text)
 {
     d->mText = text;
-    QFont font = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
+    const QFont font = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     QFontMetrics fm(font);
-    QSize minSize = fm.size(0, d->mText);
+    const QSize minSize = fm.size(0, d->mText);
     setMinimumSize(minSize);
     setPreferredSize(minSize);
 }
 
 void HudLabel::paint(QPainter *painter, const QStyleOptionGraphicsItem *, QWidget *)
 {
-    HudTheme::RenderInfo info = HudTheme::renderInfo(HudTheme::FrameWidget);
+    const HudTheme::RenderInfo info = HudTheme::renderInfo(HudTheme::FrameWidget);
     painter->setPen(info.textPen);
     painter->drawText(boundingRect(), Qt::AlignCenter, d->mText);
 }
